@@ -1,35 +1,31 @@
 //
-//	srecord - manipulate eprom load files
-//	Copyright (C) 1998-2000, 2002, 2003, 2005 Peter Miller;
-//	All rights reserved.
+//      srecord - manipulate eprom load files
+//      Copyright (C) 1998-2000, 2002, 2003, 2005-2007 Peter Miller
 //
-//	This program is free software; you can redistribute it and/or modify
-//	it under the terms of the GNU General Public License as published by
-//	the Free Software Foundation; either version 2 of the License, or
-//	(at your option) any later version.
+//      This program is free software; you can redistribute it and/or modify
+//      it under the terms of the GNU General Public License as published by
+//      the Free Software Foundation; either version 3 of the License, or
+//      (at your option) any later version.
 //
-//	This program is distributed in the hope that it will be useful,
-//	but WITHOUT ANY WARRANTY; without even the implied warranty of
-//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-//	GNU General Public License for more details.
+//      This program is distributed in the hope that it will be useful,
+//      but WITHOUT ANY WARRANTY; without even the implied warranty of
+//      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+//      GNU General Public License for more details.
 //
-//	You should have received a copy of the GNU General Public License
-//	along with this program; if not, write to the Free Software
-//	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
-//
-// MANIFEST: functions to impliment the srec_input class
+//      You should have received a copy of the GNU General Public License
+//      along with this program. If not, see
+//      <http://www.gnu.org/licenses/>.
 //
 
-#pragma implementation "srec_input"
 
 #include <errno.h>
 #include <iostream>
 using namespace std;
 #include <cstring>
 
-#include <srec/input.h>
-#include <srec/record.h>
-#include <quit/prefix.h>
+#include <lib/srec/input.h>
+#include <lib/srec/record.h>
+#include <lib/quit/prefix.h>
 
 
 srec_input::srec_input() :
@@ -79,7 +75,7 @@ srec_input::warning(const char *fmt, ...)
 }
 
 
-const string
+string
 srec_input::filename_and_line()
     const
 {
@@ -102,6 +98,6 @@ srec_input::reset_quit()
 
 
 void
-srec_input::command_line(srec_arglex *cmdln)
+srec_input::command_line(srec_arglex *)
 {
 }
