@@ -1,26 +1,22 @@
 //
-//	srecord - manipulate eprom load files
-//	Copyright (C) 1998-2002, 2005, 2006 Peter Miller;
-//	All rights reserved.
+//      srecord - manipulate eprom load files
+//      Copyright (C) 1998-2002, 2005-2007 Peter Miller
 //
-//	This program is free software; you can redistribute it and/or modify
-//	it under the terms of the GNU General Public License as published by
-//	the Free Software Foundation; either version 2 of the License, or
-//	(at your option) any later version.
+//      This program is free software; you can redistribute it and/or modify
+//      it under the terms of the GNU General Public License as published by
+//      the Free Software Foundation; either version 3 of the License, or
+//      (at your option) any later version.
 //
-//	This program is distributed in the hope that it will be useful,
-//	but WITHOUT ANY WARRANTY; without even the implied warranty of
-//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-//	GNU General Public License for more details.
+//      This program is distributed in the hope that it will be useful,
+//      but WITHOUT ANY WARRANTY; without even the implied warranty of
+//      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+//      GNU General Public License for more details.
 //
-//	You should have received a copy of the GNU General Public License
-//	along with this program; if not, write to the Free Software
-//	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
-//
-// MANIFEST: functions to impliment the srec_output_file class
+//      You should have received a copy of the GNU General Public License
+//      along with this program. If not, see
+//      <http://www.gnu.org/licenses/>.
 //
 
-#pragma implementation "srec_output_file"
 
 #include <cstdio>
 #include <errno.h>
@@ -29,7 +25,7 @@ using namespace std;
 #include <sys/types.h>
 #include <sys/stat.h>
 
-#include <srec/output/file.h>
+#include <lib/srec/output/file.h>
 
 
 bool srec_output_file::data_only_flag = false;
@@ -49,12 +45,6 @@ srec_output_file::srec_output_file() :
 }
 
 
-srec_output_file::srec_output_file(const srec_output_file &)
-{
-    fatal_error("bug (%s, %d)", __FILE__, __LINE__);
-}
-
-
 const char *
 srec_output_file::mode()
     const
@@ -63,53 +53,45 @@ srec_output_file::mode()
 }
 
 
-srec_output_file::srec_output_file(const char *fn) :
-    file_name(fn),
+srec_output_file::srec_output_file(const string &a_file_name) :
+    file_name(a_file_name),
     line_number(1),
     vfp(0),
     checksum(0),
     position(0),
     is_regular(true)
 {
-    if (file_name == string("-"))
+    if (file_name == "-")
     {
-	file_name = "standard output";
-	vfp = stdout;
-	set_is_regular();
+        file_name = "standard output";
+        vfp = stdout;
+        set_is_regular();
     }
     else
     {
-	//
-	// The call to fopen is deferred until the constructor has
-	// completed.  This is so that the virtual mode() method
-	// is available (it isn't in the base class constructor).
-	//
+        //
+        // The call to fopen is deferred until the constructor has
+        // completed.  This is so that the virtual mode() method
+        // is available (it isn't in the base class constructor).
+        //
     }
 }
 
 
-srec_output_file &
-srec_output_file::operator=(const srec_output_file &)
-{
-    fatal_error("bug (%s, %d)", __FILE__, __LINE__);
-    return *this;
-}
-
-
 void *
 srec_output_file::get_fp()
 {
     if (!vfp)
     {
-	//
-	// The call to fopen is deferred until the constructor has
-	// completed.  This is so that the virtual mode() method
-	// is available (it isn't in the base class constructor).
-	//
-	vfp = fopen(file_name.c_str(), mode());
-	if (!vfp)
-	    fatal_error_errno("open");
-	set_is_regular();
+        //
+        // The call to fopen is deferred until the constructor has
+        // completed.  This is so that the virtual mode() method
+        // is available (it isn't in the base class constructor).
+        //
+        vfp = fopen(file_name.c_str(), mode());
+        if (!vfp)
+            fatal_error_errno("open");
+        set_is_regular();
     }
     return vfp;
 }
@@ -119,9 +101,9 @@ srec_output_file::~srec_output_file()
 {
     FILE *fp = (FILE *)get_fp();
     if (fflush(fp))
-	fatal_error_errno("write");
+        fatal_error_errno("write");
     if (fp != stdout && fclose(fp))
-	fatal_error_errno("close");
+        fatal_error_errno("close");
 }
 
 
@@ -141,14 +123,14 @@ srec_output_file::put_char(int c)
     FILE *fp = (FILE *)get_fp();
     if (crlf_flag && c == '\n')
     {
-	putc('\r', fp);
-	++position;
+        putc('\r', fp);
+        ++position;
     }
     putc(c, fp);
     if (ferror(fp))
-	fatal_error_errno("write");
+        fatal_error_errno("write");
     if (c == '\n')
-	++line_number;
+        ++line_number;
     ++position;
 }
 
@@ -186,6 +168,16 @@ srec_output_file::put_3bytes(unsigned long n)
 }
 
 
+void
+srec_output_file::put_4bytes(unsigned long n)
+{
+    put_byte(n >> 24);
+    put_byte(n >> 16);
+    put_byte(n >> 8);
+    put_byte(n);
+}
+
+
 int
 srec_output_file::checksum_get()
 {
@@ -223,11 +215,11 @@ srec_output_file::seek_to(unsigned long address)
     //
     if (!is_regular)
     {
-	while (position < address)
-	    put_char(0);
+        while (position < address)
+            put_char(0);
     }
     if (address == position)
-	return;
+        return;
 
     //
     // We'll have to try a seek.
@@ -236,21 +228,21 @@ srec_output_file::seek_to(unsigned long address)
     errno = 0;
     if (fseek(fp, address, 0) < 0)
     {
-	if (errno == EINVAL && address >= 0x80000000uL)
-	{
-	    warning
-	    (
+        if (errno == EINVAL && address >= 0x80000000uL)
+        {
+            warning
+            (
                 "It appears that the implementation of fseek on your "
                 "system is unable to cope with addresses which have "
                 "the most significant bit set (this is POSIX and ANSI "
                 "C conforming behaviour).  You probably did not intend "
                 "to create a %3.1fGB file.  See the manual for a "
                 "description of the --offset filter, remembering that "
-		"you can give negative offsets.",
-		((double)address / (double)(1uL << 30))
-	    );
-	}
-	fatal_error_errno("seek 0x%lX", address);
+                "you can give negative offsets.",
+                ((double)address / (double)(1uL << 30))
+            );
+        }
+        fatal_error_errno("seek 0x%lX", address);
     }
     position = address;
 }
@@ -260,7 +252,17 @@ void
 srec_output_file::put_string(const char *s)
 {
     while (*s)
-	put_char(*s++);
+        put_char(*s++);
+}
+
+
+void
+srec_output_file::put_string(const string &s)
+{
+    const char *cp = s.c_str();
+    const char *ep = cp + s.size();
+    while (cp < ep)
+        put_char(*cp++);
 }
 
 
@@ -297,3 +299,34 @@ srec_output_file::set_is_regular()
     struct stat st;
     is_regular = fstat(fileno(fp), &st) == 0 && S_ISREG(st.st_mode);
 }
+
+
+void
+srec_output_file::fatal_alignment_error(int multiple)
+{
+    if (multiple > 4)
+    {
+        fatal_error
+        (
+            "The %s output format uses %d-byte alignment, but unaligned "
+                "data is present.  Use a \"--fill 0xNN --within <input> "
+                "--range-padding %d\" filter to fix this problem.",
+            format_name(),
+            multiple,
+            multiple
+        );
+    }
+    else
+    {
+        fatal_error
+        (
+            "The %s output format uses %d-bit data, but unaligned "
+                "data is present.  Use a \"--fill 0xNN --within "
+                "<input> --range-padding %d\" filter to fix this "
+                "problem.",
+            format_name(),
+            multiple * 8,
+            multiple
+        );
+    }
+}
